@@ -6,7 +6,7 @@ use strict;
 use vars qw{ $VERSION @ISA @EXPORT_OK };
 use vars qw{ $DEBUG $unlink $rmdir    };
 BEGIN {
-	$VERSION   = '1.53';
+	$VERSION   = '1.54';
 	# $VERSION   = eval $VERSION;
 	@ISA       = qw{ Exporter };
 	@EXPORT_OK = qw{ remove rm clear trash };
@@ -275,7 +275,7 @@ File::Remove - Remove files and directories
 
 =head1 VERSION
 
-version 1.53
+version 1.54
 
 =head1 SYNOPSIS
 
@@ -310,7 +310,7 @@ hashref.
 
 Removes files and directories.  Directories are removed recursively like
 in B<rm -rf> if the first argument is a reference to a scalar that
-evaluates to true.  If the first arguemnt is a reference to a scalar
+evaluates to true.  If the first argument is a reference to a scalar,
 then it is used as the value of the recursive flag.  By default it's
 false so only pass \1 to it.
 
@@ -529,6 +529,6 @@ from your repository :)
 
 L<https://github.com/shlomif/File-Remove>
 
-  git clone ssh://git@github.com:shlomif/File-Remove.git
+  git clone git://github.com/shlomif/File-Remove.git
 
 =cut
